package view;

import java.awt.Component;
import java.awt.GridLayout;
import java.awt.Rectangle;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLDecoder;

import javax.media.ControllerEvent;
import javax.media.ControllerListener;
import javax.media.EndOfMediaEvent;
import javax.media.Manager;
import javax.media.NoPlayerException;
import javax.media.Player;
import javax.media.RealizeCompleteEvent;
import javax.media.Time;
import javax.swing.JPanel;

/**
 * @author Mickal Martin Nevot
 * 
 * @version 1.2.0
 */
public class JPanelVideoSample1 extends JPanel implements ActionListener, ControllerListener
{
	private static final long serialVersionUID = 1L;

	private static final String BASE_VIDEO_URI = "video/";  //  @jve:decl-index=0:
	
	private static final int VIDEO_WIDTH = 320;
	private static final int VIDEO_HEIGHT = 240;
	
	private JFrameVideoSample1 frame;
	
	private Component visualComponent;

	private Player player;

	public JPanelVideoSample1(JFrameVideoSample1 frame)
	{
		super();
		
		this.frame = frame;
		
		this.setBounds(new Rectangle(0, 0, VIDEO_WIDTH, VIDEO_HEIGHT));
		
		// Pour avoir la vido de la taille du JPanel
		// (et ainsi permettre de zoomer la vido en changeant simplement la
		// taille du JPanel)
		this.setLayout(new GridLayout(1, 1));
		
		try
		{
			// getClass().getClassLoader().getResource(BASE_VIDEO_URI + "sample.mov") seul ne marche pas
			//  cause la vtust de la classe Manager
			this.player = Manager.createPlayer(new URL(URLDecoder.decode(getClass().getClassLoader().getResource(BASE_VIDEO_URI + "sample.mov").toString(), "UTF-8")));
			this.player.addControllerListener(this);
			
			this.player.start();
		}
		catch (NoPlayerException e)
		{
			e.printStackTrace();
		}
		catch (MalformedURLException e)
		{
			e.printStackTrace();
		}
		catch (IOException e)
		{
			e.printStackTrace();
		}
	}

	public void actionPerformed(ActionEvent e)
	{

	}
	
	public void controllerUpdate(ControllerEvent c) {
		/*
		 * Exemple d'excution type fonctionnelle (dcommenter la ligne ci-dessous) :
		 * [0] ControllerEvent : javax.media.TransitionEvent[source=com.sun.media.content.unknown.Handler@1172e08,previous=Unrealized,current=Realizing,target=Started]
		 * [1] ControllerEvent : javax.media.DurationUpdateEvent[source=com.sun.media.content.unknown.Handler@1172e08,duration=javax.media.Time@ab95e6
		 * [2] ControllerEvent : javax.media.RealizeCompleteEvent[source=com.sun.media.content.unknown.Handler@1172e08,previous=Realizing,current=Realized,target=Started]
		 * [3] ControllerEvent : javax.media.TransitionEvent[source=com.sun.media.content.unknown.Handler@1172e08,previous=Realized,current=Prefetching,target=Started]
		 * [4] ControllerEvent : javax.media.PrefetchCompleteEvent[source=com.sun.media.content.unknown.Handler@1172e08,previous=Prefetching,current=Prefetched,target=Started]
		 * [5] ControllerEvent : javax.media.StartEvent[source=com.sun.media.content.unknown.Handler@1172e08,previous=Prefetched,current=Started,target=Started,mediaTime=javax.media.Time@e5855a,timeBaseTime=javax.media.Time@95fd19]
		 */
		//		System.out.println("ControllerEvent : " + c.toString());
		
		if (this.player == null) {
			return;
		}

		if (c instanceof RealizeCompleteEvent) {
			if ((this.visualComponent = this.player.getVisualComponent()) != null) {
				System.out.println("RealizeCompleteEvent !");
				
				this.add(this.visualComponent);
				this.frame.validate();
			}
		} else if (c instanceof EndOfMediaEvent) {
			this.player.setMediaTime(new Time(0));
            this.player.start();
        }
	}
}